<?php
$translations = array(
	'General_Locale' => 'am_ET.UTF-8',
	'General_TranslatorName' => '<a href="http://www.addismap.com/bandira/">Alazar Tekle</a>',
	'General_TranslatorEmail' => 'info@addismap.com',
	'General_EnglishLanguageName' => 'Amharic',
	'General_OriginalLanguageName' => 'አማርኛ',
	'General_HelloUser' => 'ሃሎ, %s!',
	'General_OpenSourceWebAnalytics' => 'ክፍት የሆነ የድር ጣቢያ ማመዛዘኛ',
	'General_API' => 'ኤፒአይI',
	'General_Widgets' => 'Widgets',
	'General_Settings' => 'ቅንብሮች',
	'General_GiveUsYourFeedback' => 'እባክዎ መልሰህ መግብ ስጡን!',
	'General_Unknown' => 'ያልታወቀ',
	'General_Required' => '%s አስፈላጊ',
	'General_Error' => 'ስህተት',
	'General_Warning' => 'ማስጠንቀቂያ',
	'General_BackToHomepage' => 'ወደ ፒዊክ መነሻ ገፅ ተመለስ',
	'General_Yes' => 'አዎን',
	'General_No' => 'የለም',
	'General_Delete' => 'ሰርዝ',
	'General_Edit' => 'አርትእ',
	'General_Ok' => 'ይሁን',
	'General_Close' => 'ዝጋ',
	'General_Logout' => 'ውጣ',
	'General_Done' => 'አልቋል',
	'General_LoadingData' => 'ውሂብ በማስገባት ላይ...',
	'General_Loading_js' => 'በማስገባት ላይ...',
	'General_Next' => 'ቀጥል',
	'General_Previous' => 'ቀደም ያለ',
	'General_Search' => 'ፈልግ',
	'General_Others' => 'ለሎች',
	'General_Table' => 'ሰንጠረዥ',
	'General_Piechart' => 'አምባሻ ገበታ',
	'General_TagCloud' => 'መለያ Cloud',
	'General_VBarGraph' => 'አቀባዊ አሞሌ ግራፍ',
	'General_Refresh' => 'ገፁን አድስ',
	'General_Visitors' => 'ጎብኝዎች',
	'General_Export' => 'ላክ',
	'General_ErrorRequest' => 'Oops… problem during the request, please try again.',
	'General_ColumnNbUniqVisitors' => 'ብቸኛ ጎብኚዎች',
	'General_ColumnNbVisits' => 'ጉብኝቶች',
	'General_ColumnNbActions' => 'ርምጃዎች',
	'General_ColumnMaxActions' => 'በአንድ ጉብኝት የተወሰዱ ከፍተኛ ርምጃዎች',
	'General_ColumnSumVisitLength' => 'በጎብኚዎች የተፈጀ ከፍተኛ ሰዓት (በሰከንዶች)',
	'General_ColumnLabel' => 'መሰየሚያ',
	'General_ColumnActionsPerVisit' => 'ርምጃ ከጉብኝት',
	'General_ColumnAvgTimeOnSite' => 'በየድር ጣቢያ የተፈጀ አማካይ ሰዓት',
	'General_ColumnBounceRate' => 'ተመላሽ',
	'General_ColumnPageviews' => 'ገፅ ትይታዎች',
	'General_ColumnUniquePageviews' => 'ብቸኛ ገፅ ትይታዎች',
	'General_ColumnValuePerVisit' => 'እሴት በጉብኝት',
	'General_ColumnVisitsWithConversions' => 'ጉብኝት ከልወጣዎች ጋር',
	'General_Save' => 'አስቀምጥ',
	'General_Website' => 'ድር ጣቢያ',
	'General_NoDataForGraph' => 'ለዚህ ግራፍ ምንም ውሂብ የለም',
	'General_NoDataForTagCloud' => 'ለዚህ መለያ ክላውድ ምንም ውሂብ የለም.',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%1$s ፒዊክ %2$s በትብብር የተዘረጋ ፕሮጀክት ነው። %3$s ፒዊክ ከተስማማችሁ ድጋፍ መሰጠት ትችላላችሁ! ለፒዊክ ፕሮጀክት %4$s እንዴት አስተዋፃኦ ማድረግ እንደሚችሉ ይመልከቱ?%5$s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'ፒዊክን %1$s ማግኘት ይቻላል። %2$s እባክዎን ያልቁት!%3$s (ለውጦቹን%4$s ይመልከቱ%5$s).',
	'General_BackToPiwik' => 'ወደፒዊክ ተመለስ',
	'General_ShortMonth_1' => 'ጥር',
	'General_ShortMonth_2' => 'የካ',
	'General_ShortMonth_3' => 'መጋ',
	'General_ShortMonth_4' => 'ሚያ',
	'General_ShortMonth_5' => 'ግን',
	'General_ShortMonth_6' => 'ሰኔ',
	'General_ShortMonth_7' => 'ሐም',
	'General_ShortMonth_8' => 'ነሐሴ',
	'General_ShortMonth_9' => 'መስከ',
	'General_ShortMonth_10' => 'ጥቅ',
	'General_ShortMonth_11' => 'ሀዳ',
	'General_ShortMonth_12' => 'ታህ',
	'General_LongMonth_1' => 'ጥር',
	'General_LongMonth_2' => 'የካቲት',
	'General_LongMonth_3' => 'መጋቢት',
	'General_LongMonth_4' => 'ሚያዝያ',
	'General_LongMonth_5' => 'ግንቦት',
	'General_LongMonth_6' => 'ሰኔ',
	'General_LongMonth_7' => 'ሐምሌ',
	'General_LongMonth_8' => 'ነሐሴ',
	'General_LongMonth_9' => 'መስከረም',
	'General_LongMonth_10' => 'ጥቅምት',
	'General_LongMonth_11' => 'ሀዳር',
	'General_LongMonth_12' => 'ታህሳስ',
	'General_ShortDay_1' => 'ሰኞ',
	'General_ShortDay_2' => 'ማክ',
	'General_ShortDay_3' => 'ረቡ',
	'General_ShortDay_4' => 'ሐሙ',
	'General_ShortDay_5' => 'አር',
	'General_ShortDay_6' => 'ቅዳ',
	'General_ShortDay_7' => 'እሁ',
	'General_LongDay_1' => 'ሰኞ',
	'General_LongDay_2' => 'ማክሰኞ',
	'General_LongDay_3' => 'ረቡዕ',
	'General_LongDay_4' => 'ሐሙስ',
	'General_LongDay_5' => 'አርብ',
	'General_LongDay_6' => 'ቅዳሜ',
	'General_LongDay_7' => 'እሁድ',
	'Actions_Actions' => 'ርምጃዎች',
	'Actions_SubmenuPages' => 'ገፆች',
	'Actions_SubmenuOutlinks' => 'ወጪአገናኞች',
	'Actions_SubmenuDownloads' => 'የወረዱ',
	'Actions_ColumnClicks' => 'ጠቃድርጎች',
	'Actions_ColumnUniqueClicks' => 'ብቸኛ ጠቅአድርጎች',
	'Actions_ColumnDownloads' => 'የወረዱ',
	'Actions_ColumnUniqueDownloads' => 'ብቸኛ የወረዱ',
	'Actions_ColumnPageName' => 'የገፅ ስም',
	'Actions_ColumnClickedURL' => 'ጠቅ አድርግ ዩ አር ኤል',
	'Actions_ColumnDownloadURL' => 'የማውረጃ ዩ አር ኤል',
	'API_LoadedAPIs' => 'ማስጋባት ተሳክቷል %s ኤፒአይዎች',
	'CoreHome_CategoryNoData' => 'በዚህ ፈርጅ ምንም ውሂብ የለም. "ሁሉንም ምድብ" ለማጠቃለል ይሞክሩ።',
	'CoreHome_ShowJSCode' => 'ለማስገባት የጃቫ ስክሪፕትን ኮድ አሳይ',
	'CoreHome_PageOf_js' => '%1$s የ %2$s',
	'CoreHome_PeriodDay' => 'ቀን',
	'CoreHome_PeriodWeek' => 'ሳምንት',
	'CoreHome_PeriodMonth' => 'ወር',
	'CoreHome_PeriodYear' => 'ዓመት',
	'CoreHome_PeriodDays' => 'ቀናት',
	'CoreHome_PeriodWeeks' => 'ሳምንታት',
	'CoreHome_PeriodMonths' => 'ወራት',
	'CoreHome_PeriodYears' => 'ዓመታት',
	'CoreHome_DaySu_js' => 'እሁ',
	'CoreHome_DayMo_js' => 'ሰኞ',
	'CoreHome_DayTu_js' => 'ማክ',
	'CoreHome_DayWe_js' => 'ረቡ',
	'CoreHome_DayTh_js' => 'ሐሙ,',
	'CoreHome_DayFr_js' => 'አርብ',
	'CoreHome_DaySa_js' => 'ቅዳ',
	'CoreHome_MonthJanuary_js' => 'ጥር',
	'CoreHome_MonthFebruary_js' => 'የካቲት',
	'CoreHome_MonthMarch_js' => 'መጋቢት',
	'CoreHome_MonthApril_js' => 'ሚያዚያ',
	'CoreHome_MonthMay_js' => 'ግንቦት',
	'CoreHome_MonthJune_js' => 'ሰኔ',
	'CoreHome_MonthJuly_js' => 'ሐምሌ',
	'CoreHome_MonthAugust_js' => 'ነሐሴ',
	'CoreHome_MonthSeptember_js' => 'መስከረም',
	'CoreHome_MonthOctober_js' => 'ጥቅምት',
	'CoreHome_MonthNovember_js' => 'ህዳር',
	'CoreHome_MonthDecember_js' => 'ታህሳስ',
	'CorePluginsAdmin_Plugins' => 'ተሰኪዎች',
	'CorePluginsAdmin_PluginsManagement' => 'ተሰኪዎች መመነጅ',
	'CorePluginsAdmin_MainDescription' => 'ተሰኪዎች የፒዊክን አገልግሎት ያራዝማሉ ያሰፋሉ። ተሰኪዎች አንዴ ከተጫኑ እዚሁ ጋር መገበርም ማቦዘንም ይቻላል።',
	'CorePluginsAdmin_Plugin' => 'ተሰኪ',
	'CorePluginsAdmin_Version' => 'ስሪት',
	'CorePluginsAdmin_Status' => 'ሁኔታ',
	'CorePluginsAdmin_Action' => 'ርምጃ',
	'CorePluginsAdmin_PluginHomepage' => 'የተሰኪ መነሻ ገፅ',
	'CorePluginsAdmin_Activated' => 'የተገበረ',
	'CorePluginsAdmin_Active' => 'ገባሪ',
	'CorePluginsAdmin_Inactive' => 'ያልተመረጠ',
	'CorePluginsAdmin_Deactivate' => 'አቦዝን',
	'CorePluginsAdmin_Activate' => 'አግብር',
	'CorePluginsAdmin_MenuPlugins' => 'ተሰኪዎች',
	'CoreUpdater_UpdateTitle' => 'ፒዊክ › አልቅ',
	'CoreUpdater_DatabaseUpgradeRequired' => 'የውሂብ ጎታ ማላቅ ያስፈልጋል',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'የፒዊክ የውሂብ ጎታዎ ቀኑ ሰላለፈበት ከመቀጠልዎ በፊት ማላቅ ያስፈልገዋል',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'የፒዊክ የውሂብ ጎታዎ ከ %1$sስሪት ወደ  %2$sስሪት ይልቃል.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'የሚከተሉት ተሰኪዎችም ይልቃሉ: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'የውሂብ ጎታ ማላቅ ሂደቱ ጥቂት ጊዜ ስለሚወስድ እባክዎ በትዕግስት ይጠብቁ',
	'CoreUpdater_UpgradePiwik' => 'ፒዊክን አልቅ',
	'CoreUpdater_HelpMessageContent' => 'የ %1$s ፒዊክን ኤፍ ኤ ኪው %2$s ይመልከቱ ምከነያቱም ባማላቀ ወቅት በጣም ተደጋጋሚ ለሆኑ ስህተቶች መልስ የሰጣልና %3$s የስርዓት አስተዳዳሪዎን ይጠይቁ - ከአገልጋይ ወይም ማይ ኤስ ኪው ኤል መዋቅር ጋር ተዛማጅነት ላላቸው ስህተቶች ርዳታ ሊያገኙ ይችላሉ',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'በማላቅ ሂደት ላይ ያጋጠመ ከባድ እንከን:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'ከላይ ያለው የስህተት ኮር መልእክት ነው። ምክንያቱን ለማስረዳት አጋዥ ሊሆን ይችላል ነገር ግን ተጨማሪ ርዳታ ከፈለጉ እባክዎ:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'ማላቁ በሚጋባ ተጠናቅቋል ቢሆንም በሂደቱ ላይ ችግሮች ነበሩ። ዝርዝር ከፈለጉ ከላይ የተቀመጡትን መግለጫዎች ያንቡ። ለተጨማሪ ርዳታ፡',
	'CoreUpdater_UpgradeComplete' => 'ማላቅ ተጠናቋል!',
	'CoreUpdater_WarningMessages' => 'የማስጠንቀቂያ መልዕክቶች:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'ተሰኪዎችን በማላቅ ሂደት ያጋጠሙ ስህተቶች:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'የሚከተሉትን ተሰኪዎች በራስሰር አቦዝነናል: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'ፒዊክን ማላቅ በተሳካ ሁኔታ ተጠናቋል!',
	'CoreUpdater_ContinueToPiwik' => 'ወደ ፒዊክ ቀጥል',
	'CoreUpdater_UpdateAutomatically' => 'ራስሰር አልቅ',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'ለማላቅ ዝግጁ የሆነ የፒዊክ ሰሪት አለ',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'ወደ ስሪት %s ራስሰር ማላቅ ወይም አካታቾቹን አውርዶ በጅ መጫን ይቻላል ይቻላል:',
	'CoreUpdater_DownloadX' => 'አውርድ %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'ፒዊክ አንድ ጠቅ አርግ ማላቅ ተሰርዟል።  ከላይ ያለውን የስህተት መልዕክት መጠገን ካልቻልክ ፒዊክን በእጅ እንድታልቅትመከራለህ። %1$s ለመጀመር የ %2$sማላቂያ ስነዳ %3$sተመልከት!',
	'CoreUpdater_VerifyingUnpackedFiles' => 'የተበተኑትን ፋይሎች በመበተን ላይ',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'የውቅረት ፋይሉን መጠባበቂያ  በመፍጠር ላይ %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'አዲሱን ስሪት በመጫን ላይ',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'የፒዊክ ማላቅ ተሳክቷል!',
	'Dashboard_Dashboard' => 'ዳሽቦርድ',
	'Dashboard_DeleteWidgetConfirm' => 'እርግጠኛ ነህ ይህ widget ከዳሽቦርድ ይሰረዝ?',
	'Dashboard_SelectWidget' => 'ወደ ዳሽቦርድ የሚጨመረውን widget ምረጥ',
	'Dashboard_AddPreviewedWidget_js' => 'ቅድመ እይታ የተሰጠውን widget ወደ ዳሽቦርዱ ጨምር',
	'Dashboard_WidgetPreview_js' => 'የWidget ቅድመእይታ',
	'Dashboard_Close_js' => 'ዝጋ',
	'Dashboard_TitleWidgetInDashboard_js' => 'Widget ወደዳሽቦርዱ አስቀድሞ ገብቷል',
	'Dashboard_TitleClickToAdd_js' => 'ወደ ዳሽቦርዱ ለመጨመር ጠቅ አድርግ',
	'Dashboard_LoadingWidget_js' => 'widget በመጫን ላይ, እባክዎ ይጠበቁ...',
	'Dashboard_WidgetNotFound_js' => 'Widget አልተገኘም',
	'DBStats_DatabaseUsage' => 'የውሂብ ጎታ አጠቃቀም',
	'DBStats_MainDescription' => 'ፒዊክ የድር ምዘናዎቹን ውሂብ በመይ ኤስ ኪው ኤል ይውሂብ ጎታ ውስጥ በማከማቸት ላይ ነው። በአሁን ወቅት የፒዊክ ሰንጠረዦች እየተጠቀሙ ያሉት %s።',
	'DBStats_Table' => 'ሰንጠረዥ',
	'DBStats_DataSize' => 'የውሂብ መጠን',
	'DBStats_IndexSize' => 'የመረጃ ጠቋሚ መጠን',
	'DBStats_TotalSize' => 'አጠቃላይ መጠን',
	'Goals_ColumnConversions' => 'ልወጣዎች',
	'Goals_ColumnRevenue' => 'ገቢ',
	'Installation_Installation' => 'መጫኛ',
	'Installation_InstallationStatus' => 'የመጫኛ ሁኔታ',
	'Installation_PercentDone' => '%s %% አልቋል',
	'Installation_NoConfigFound' => 'የፒዊክ ውቅረት ፋይል ሊገኝ አልቻለም እና እርስዎ የፒዊክ ገፅ ለመድረስ እየሞከሩ ነው። <br /><b>  » እርስዎ <a href=\'index.php\'>ፒዊክን አሁን መጫን ይችላሉ</a></b><br /><small>ፒዊክን ከዚህ ቀደም ጭነው ከነበረ እና በዲቢዎ ላይ የተወሰኑ ሰንጠረዦች ካለዎ የነበሩትን ሰንጠረዦች ደግመው መጠቀምና የነበረዎትን ውሂብ ማስቀመጥ ይችላሉ!</small>',
	'Installation_JsTag' => 'የጃቫ ስክሪፕት መለያ',
	'Installation_Congratulations' => 'እንኳን ደስያለዎ',
	'Installation_CongratulationsHelp' => '<p>እንኳን ደስያለዎ! የፒዊክ መጫንዎ ተሳክቷል።</p><p>የጃቫ ስክሪፕትዎ ቾድ በሁሉ ገፆች ላይ መግባቱን ያረጋግጡና የመጀመሪያ ጎበኚዎችዎን ይጠብቁ!</p>',
	'Installation_ContinueToPiwik' => 'ወደ ፒዊክ ይቀጥሉ',
	'Installation_SetupWebsite' => 'ድር ጣቢያ ጫን',
	'Installation_SetupWebsiteError' => 'ድር ጣቢያውን በመጫን ጊዜ ስህተት አጋጥሟል',
	'Installation_SuperUserLogin' => 'ሊቀ ተገልጋይ ግባ',
	'Installation_Password' => 'የይለፍ ቃል',
	'Installation_PasswordRepeat' => 'የይለፍ ቃል (ድገም)',
	'Installation_Email' => 'ኢ-ሜይል',
	'Installation_SecurityNewsletter' => 'ከዋነኛ የፒዊክ ማላቂያዎች እና የጥበቃ ማስጠንቀቂያዎች ጋር ኢ-ሜይል አድርግልኝ',
	'Installation_CommunityNewsletter' => 'ከማህበረሰብ አልቅ ጋር ኢ-ሜይል አድርግልኝ(አዲስ ተሰኪዎች, አዲስ ባህርይዎች, ወዘተ.)',
	'Installation_PasswordDoNotMatch' => 'የይለፍ ቃሉ አቻ አይደለም',
	'Installation_SystemCheck' => 'ስርዓት አረጋግጥ',
	'Installation_SystemCheckPhp' => 'የፒ ኤች ፒ ስሪት',
	'Installation_SystemCheckWriteDirs' => 'ማውጫ ከፃፍ መድረሻ ጋር',
	'Installation_SystemCheckWriteDirsHelp' => 'ይህንን ስህተት በሊኑክስ ስርዓት ላይ ለማስተካከል የሚከተሉትን ትእዛዝ(ዞች) ይተይቡ',
	'Installation_SystemCheckMemoryLimit' => 'የማህደረ ትውስታ ገደብ',
	'Installation_SystemCheckMemoryLimitHelp' => 'ከፍተኛ የጎብኚ መጨናነቅ ባለባችው ድር ጣቢያዎች ላይ የምዝገባ ሂድት በወቅቱ ከተፈቀደው ብላይ ብዙ ማህደረ ትውስታ ሊያስፈልገው ይችላል።<br />የማህደረ ትውስታውን ገደብ መመሪያ በ php.ini ፋይል ውስጥ አስፈላጊ ከሆነ መመልከት ትችላለህ።',
	'Installation_SystemCheckGD' => 'ጂዲ > 2.x (ንድፋንድፍ)',
	'Installation_SystemCheckGDHelp' => 'የብልጭታ መስመሮቹ (ትናንሽ ግራፎች)አይሰሩም',
	'Installation_SystemCheckTimeLimitHelp' => 'ከፍተኛ የትራፊክ መጨናነቅ ያለባቸው የድር ጣቢያዎች ላይ የምዝገባ ሂደቱን ማስፈፀም ከተፈቀደው ሰዓት በላይ ሊፈልግ ይችላል።<br />ከፍተኛ_የማስፈፀሚያ_ጊዜ መመሪያውን በ php.ini ፋይል ውስጥ አስፈላጊ ከሆነ መመልከት ትችላለህ።',
	'Installation_SystemCheckError' => 'ስህተት ተከስቷል - ከመቀጠልዎ በፊት መጠገን አለበት',
	'Installation_SystemCheckWarning' => 'ፒዊክ በመደበኛነት ሊሰራ ይችላል ነገርግን አንዳንድ ባህርይዎች ጠፍተው ሊሆን ይችላል',
	'Installation_Tables' => 'ሠንጠረዦቹን በመፍጠር ላይ',
	'Installation_TablesWithSameNamesFound' => 'አንዳንድ %1$s በውሂብ ጎታ ውስጥ ያሉ ሰንጠረዦች%2$s ፒዊክ ለመፍጠር እየሞከረ ካሉት ሰንጠረዦች ጋር ተመሳሳይ ስም አላቸው',
	'Installation_TablesFound' => 'የሚከተሉት ሰንጠረዦች በውሂብ ጎታዎች ውስጥ ተገኝተዋል',
	'Installation_TablesWarningHelp' => 'ቀደም ሲል የነበሩትን የውሂብ ጎታዎች ስንጠረዥመልሰህ ለመጠቀም ምረጥ ወይም በውሂብ ጎታዎቹ ውስጥ ያሉትን ውሂቦች ለማጥፋት ንፁህ ጫን ምረጥ',
	'Installation_TablesReuse' => 'ቀደም ሲል የነበሩትን ሰንጠረዦች መልሰህ ተጠቀም',
	'Installation_TablesDelete' => 'የተገኙትን ሰንጠረዦች ሰርዝ',
	'Installation_TablesDeletedSuccess' => 'ቀደም ሲል የነበሩት የፒዊክ ሰንጠረዦች በሚገባ ተሰርዘዋል',
	'Installation_TablesCreatedSuccess' => 'ሰንጠረዦች በሚገባ ተፈጥረዋል!',
	'Installation_DatabaseCreatedSuccess' => 'የውሂብ ጎታ %s በሚገባ ተፈጥሯል!',
	'Installation_GoBackAndDefinePrefix' => 'ወደኋላ ተመለስና ለፒዊክ ሰንጠረዦቹ ቅድም ቅጥያውን በይን',
	'Installation_ConfirmDeleteExistingTables' => 'እርግጠኛ ነህ ይህንን ሰንጠረዥ ከውሂብ ጎታህ ውስጥ : %s መሰረዝ ትፈልጋለህ? ማስጠንቀቂያ: ከዚህ ሰንጠረዥ ውስጥ የጠፉ ውሂቦች ተመልሰው ሊገኙ አይችሉም!',
	'Installation_Welcome' => 'እንኳን ደህና መጡ!',
	'Installation_WelcomeHelp' => '<p>ፒዊክ ክፍት የሆነ የድር ማመዛዘኛ ሶፍትዌር ሲሆን ከጎብኚዎችዎ የሚፈልጉትን መረጃ ለማግኘት ቀላል ያደርገዋል።</p><p>ይህ ሂደት ወደ ቀላል ደረጃዎች %s የተከፋፈለ ሲሆን ወደ 5 ደቂቃ አካባቢ ይፈጃል።</p>',
	'Installation_ErrorInvalidState' => 'ስህተት: የመጫኑን ሂደት የዘለልክ ይመስላል ወይም ኩኪዎቹ ቦዝነዋል ውይም የፒዊክ ውቅረት ፋይል አስቀድሞ ተፈጥሯል። %1$sኩኪዎቹ መንቃታቸውን አረጋግጥ%2$s እና ተመልሰህ %3$s ወደ መጫኛው የመጀመሪያ ገፅ ሂድ። %4$s.',
	'Login_LoginPasswordNotCorrect' => 'የተጠቃሚ ስም እና የይለፍ ቃል ትክክል አይደለም',
	'Login_Password' => 'የይለፍ ቃል',
	'Login_LoginOrEmail' => 'ግባ ወይም ኢ-ሜይል',
	'Login_LogIn' => 'ግባ',
	'Login_Logout' => 'ውጣ',
	'Login_LostYourPassword' => 'የይለፍ ቃል ጠፋብህ?',
	'Login_RemindPassword' => 'የይለፍ ቃል አስታውስ',
	'Login_PasswordReminder' => 'እባክህ የተጠቃሚ ስም ወይም የኢ-ሜይል አድራሻ አስገባ. አዲስ የይለፍ ቃል በኢ-ሜይል ይላካል።',
	'Login_InvalidUsernameEmail' => 'የተሳሳት የተጠቃሚ ስም እና/ወይም ኢ-ሜይል አድራሻ',
	'Login_MailTopicPasswordRecovery' => 'የይለፍ ቃል ማግኛ',
	'Login_PasswordSent' => 'የይለፍ ቃል አሁን ተልኳል። ኢ-ሜይልዎን አሁን ይመልከቱ',
	'Login_ContactAdmin' => 'ተገቢው ምክንያት: አስተናጋጅዎ የ ሜይል() ተግባርን አቦዝኖት ሊሆን ይችላል። <br />እባክዎ የፒዊክ መናጅዎን ያነጋግሩ',
	'Provider_WidgetProviders' => 'አቅራቢዎች',
	'Provider_ColumnProvider' => 'አቅራቢ',
	'Provider_SubmenuLocationsProvider' => 'መገኛ እና አቅራቢ',
	'Referers_Referers' => 'አመላካቾች',
	'Referers_SearchEngines' => 'የመፈለጊያ ሞተሮች',
	'Referers_Keywords' => 'ቁልፍ ቃላት',
	'Referers_DirectEntry' => 'ቀጥተኛ ምዝግብ',
	'Referers_Websites' => 'ድር ጣቢያዎች',
	'Referers_Campaigns' => 'Campaigns',
	'Referers_Evolution' => 'Evolution በክፍለ ጊዜው',
	'Referers_Type' => 'የምልከታ ዓይነት',
	'Referers_ColumnRefererType' => 'የአመላካች ዓይነት',
	'Referers_ColumnSearchEngine' => 'የመፈለጊያ ሞተሮች',
	'Referers_ColumnWebsite' => 'ድር ጣቢያዎች',
	'Referers_ColumnWebsitePage' => 'የድር ጣቢያዎች ገፅ',
	'Referers_ColumnKeyword' => 'ቁልፍ ቃላት',
	'Referers_ColumnCampaign' => 'Campaign',
	'Referers_DetailsByRefererType' => 'ዝርዝር በአመላካች ዓይነት',
	'Referers_TypeDirectEntries' => '%s ቀጥተኛ ምዝግቦች',
	'Referers_TypeSearchEngines' => '%s ከመፈለጊያ ሞተሮች',
	'Referers_TypeWebsites' => '%s ከድር ጣቢያዎች',
	'Referers_TypeCampaigns' => '%s ከ campaigns',
	'Referers_Distinct' => 'የተለዩ ምልከታዎች በአመላካች ዓይነት',
	'Referers_DistinctSearchEngines' => 'የተለዩ የመፈለጊያ ሞተሮች',
	'Referers_DistinctKeywords' => 'የተለዩ ቁልፍ ቃላት',
	'Referers_DistinctCampaigns' => 'የተለዩ campaigns',
	'Referers_DistinctWebsites' => 'የተለዩ ድር ጣቢያዎች',
	'Referers_SubmenuSearchEngines' => 'የመፈለጊያ ሞተሮች እና ቁልፍ ቃላት',
	'Referers_SubmenuWebsites' => 'ድር ጣቢያዎች',
	'Referers_SubmenuCampaigns' => 'Campaigns',
	'Referers_WidgetKeywords' => 'የቁልፍ ቃላት ዝርዝር',
	'Referers_WidgetCampaigns' => 'የCampaigns ዝርዝር',
	'Referers_WidgetExternalWebsites' => 'የውጫዊ ድር ጣቢያዎች ዝርዝር',
	'Referers_WidgetSearchEngines' => 'ምርጥ የመፈለጊያ ሞተር',
	'Referers_WidgetOverview' => 'አጠቃላይ እይታ',
	'SitesManager_Sites' => 'ድር ጣቢያ',
	'SitesManager_WebsitesManagement' => 'የድር ጣቢያ ምነጃ',
	'SitesManager_MainDescription' => 'የድር ማመዛዘኛ ሪፖርት ድር ጣቢያ ያስፈልጋቸዋል! ጨምር፣ አልቅ፣ ድር ጣቢያ ሰርዝ እና በገፅህ ላይ ለማስገባት የፈለግከውን የጃቫ ስክሪፕት አሳይ',
	'SitesManager_JsTrackingTag' => 'የጃቫ ስክሪፕት ዱካ መከተያ መለያ',
	'SitesManager_JsTrackingTagHelp' => 'በሁሉም ገፆች ለማካተት እንዲያስችልህ የጃቫ ስክሪፕት ዱካ መከተያ መለያ እዚህ አለ',
	'SitesManager_ShowTrackingTag' => 'የዱካ መከተያ መለያ አሳይ',
	'SitesManager_NoWebsites' => 'ለታስተዳድረው የምትችለው ምንም አይነት ድር ጣቢያ የለም',
	'SitesManager_AddSite' => 'አዲስ ድር ጣቢያ ጨምር',
	'SitesManager_Urls' => 'ዩ አር ኤሎች',
	'SitesManager_MenuSites' => 'ድር ጣቢያዎች',
	'SitesManager_DeleteConfirm_js' => 'እርግጠኛ ነህ ድር ጣቢያውን ለመሰረዝ %s?',
	'SitesManager_ExceptionDeleteSite' => 'የተመዘገበ ብቸኛው ድር ጣቢያ ስለሆነ ለመዘረዝ አይቻልም። በመጀመሪያ አዲስ ድር ጣቢያ ጨምርና ቀጠሎ ይህንን ሰርዝ።',
	'SitesManager_ExceptionNoUrl' => 'ለዚህ ድር ጣቢያ ቢያንስ አንድ ዩ አር ኤል ማምር አለብህ።',
	'SitesManager_ExceptionEmptyName' => 'የድር ጣቢያው ስም ባዶ መሆን አይችልም።',
	'TranslationsAdmin_MenuTranslations' => 'ትርጉሞች',
	'TranslationsAdmin_MenuLanguages' => 'ቋንቋዎች',
	'TranslationsAdmin_LanguageCode' => 'የቋንቋ ኮድ',
	'TranslationsAdmin_Plugin' => 'ተሰኪ',
	'TranslationsAdmin_Definition' => 'ብየና',
	'TranslationsAdmin_DefaultString' => 'ነባሪ መዋቅር (እንግሊዘኛ)',
	'TranslationsAdmin_TranslationString' => 'የትርጉም መዋቅር (የአሁኑ ቋንቋ: %s)',
	'TranslationsAdmin_Translations' => 'ትርጉሞች',
	'TranslationsAdmin_FixPermissions' => 'እባክህ የሥርዓተ ፋይል ፈቃዶቹን ጠግን',
	'TranslationsAdmin_AddLanguage' => 'ቋንቋ ጨምር',
	'TranslationsAdmin_Export' => 'ቋንቋ ላክ',
	'TranslationsAdmin_Import' => 'ቋንቋ አስመጣ',
	'UserCountry_Country' => 'ሀገር',
	'UserCountry_Continent' => 'አህጉር',
	'UserCountry_DistinctCountries' => '%s የተለዩ ሀገራት',
	'UserCountry_SubmenuLocations' => 'አቀማመጦች',
	'UserCountry_WidgetContinents' => 'የጎብኚዎች አህጉራት',
	'UserCountry_WidgetCountries' => 'የጎብኚዎች ሀገራት',
	'UserCountry_country_ac' => 'Ascension Islands',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'United Arab Emirates',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua and Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albania',
	'UserCountry_country_am' => 'Armenia',
	'UserCountry_country_an' => 'Netherlands Antilles',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarctica',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'American Samoa',
	'UserCountry_country_at' => 'Austria',
	'UserCountry_country_au' => 'Australia',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => 'Aland Islands',
	'UserCountry_country_az' => 'Azerbaijan',
	'UserCountry_country_ba' => 'Bosnia and Herzegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgium',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgaria',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'Saint Barthelemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Bruneo',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brazil',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet Island',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Belarus',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Canada',
	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
	'UserCountry_country_cd' => 'Congo, The Democratic Republic of the',
	'UserCountry_country_cf' => 'Central African Republic',
	'UserCountry_country_cg' => 'Congo',
	'UserCountry_country_ch' => 'Switzerland',
	'UserCountry_country_ci' => 'Cote D\'Ivoire',
	'UserCountry_country_ck' => 'Cook Islands',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Cameroon',
	'UserCountry_country_cn' => 'China',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Clipperton Island',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbia Montenegro',
	'UserCountry_country_cu' => 'Cuba',
	'UserCountry_country_cv' => 'Cape Verde',
	'UserCountry_country_cx' => 'Christmas Island',
	'UserCountry_country_cy' => 'Cyprus',
	'UserCountry_country_cz' => 'Czech Republic',
	'UserCountry_country_de' => 'Germany',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Denmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Dominican Republic',
	'UserCountry_country_dz' => 'Algeria',
	'UserCountry_country_ea' => 'Ceuta, Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estonia',
	'UserCountry_country_eg' => 'Egypt',
	'UserCountry_country_eh' => 'Western Sahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spain',
	'UserCountry_country_et' => 'Ethiopia',
	'UserCountry_country_eu' => 'European Union',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falkland Islands (Malvinas)',
	'UserCountry_country_fm' => 'Micronesia, Federated States of',
	'UserCountry_country_fo' => 'Faroe Islands',
	'UserCountry_country_fr' => 'France',
	'UserCountry_country_fx' => 'France, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Great Britain',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgia',
	'UserCountry_country_gf' => 'French Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Greenland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Equatorial Guinea',
	'UserCountry_country_gr' => 'Greece',
	'UserCountry_country_gs' => 'South Georgia and the South Sandwich Islands',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard Island and McDonald Islands',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Croatia',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Hungary',
	'UserCountry_country_ic' => 'Canary Islands',
	'UserCountry_country_id' => 'Indonesia',
	'UserCountry_country_ie' => 'Ireland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Man Island',
	'UserCountry_country_in' => 'India',
	'UserCountry_country_io' => 'British Indian Ocean Territory',
	'UserCountry_country_iq' => 'Iraq',
	'UserCountry_country_ir' => 'Iran, Islamic Republic of',
	'UserCountry_country_is' => 'Iceland',
	'UserCountry_country_it' => 'Italy',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordan',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kyrgyzstan',
	'UserCountry_country_kh' => 'Cambodia',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Comoros',
	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
	'UserCountry_country_kp' => 'Korea, Democratic People\'s Republic of',
	'UserCountry_country_kr' => 'Korea, Republic of',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman Islands',
	'UserCountry_country_kz' => 'Kazakhstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Lebanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Lithuania',
	'UserCountry_country_lu' => 'Luxembourg',
	'UserCountry_country_lv' => 'Latvia',
	'UserCountry_country_ly' => 'Libya',
	'UserCountry_country_ma' => 'Morocco',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldova, Republic of',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagascar',
	'UserCountry_country_mh' => 'Marshall Islands',
	'UserCountry_country_mk' => 'Macedonia',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongolia',
	'UserCountry_country_mo' => 'Macau',
	'UserCountry_country_mp' => 'Northern Mariana Islands',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauritania',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldives',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexico',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Mozambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'New Caledonia',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk Island',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Netherlands',
	'UserCountry_country_no' => 'Norway',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutral Zone',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'New Zealand',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'French Polynesia',
	'UserCountry_country_pg' => 'Papua New Guinea',
	'UserCountry_country_ph' => 'Philippines',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Poland',
	'UserCountry_country_pm' => 'Saint Pierre and Miquelon',
	'UserCountry_country_pn' => 'Pitcairn',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestinian Territory',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Reunion Island',
	'UserCountry_country_ro' => 'Romania',
	'UserCountry_country_rs' => 'Serbia',
	'UserCountry_country_ru' => 'Russia',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudi Arabia',
	'UserCountry_country_sb' => 'Solomon Islands',
	'UserCountry_country_sc' => 'Seychelles',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sweden',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Saint Helena',
	'UserCountry_country_si' => 'Slovenia',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakia',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Suriname',
	'UserCountry_country_st' => 'Sao Tome and Principe',
	'UserCountry_country_su' => 'Old U.S.S.R',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrian Arab Republic',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks and Caicos Islands',
	'UserCountry_country_td' => 'Chad',
	'UserCountry_country_tf' => 'French Southern Territories',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tajikistan',
	'UserCountry_country_tk' => 'Tokelau',
	'UserCountry_country_tl' => 'East Timor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisia',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => 'East Timor',
	'UserCountry_country_tr' => 'Turkey',
	'UserCountry_country_tt' => 'Trinidad and Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania, United Republic of',
	'UserCountry_country_ua' => 'Ukraine',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'United Kingdom',
	'UserCountry_country_um' => 'United States Minor Outlying Islands',
	'UserCountry_country_us' => 'United States',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatican City',
	'UserCountry_country_vc' => 'Saint Vincent and the Grenadines',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Virgin Islands, British',
	'UserCountry_country_vi' => 'Virgin Islands, U.S.',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis and Futuna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Yemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Yugoslavia',
	'UserCountry_country_za' => 'South Africa',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europe',
	'UserCountry_continent_afr' => 'Africa',
	'UserCountry_continent_asi' => 'Asia',
	'UserCountry_continent_amn' => 'North America',
	'UserCountry_continent_ams' => 'South and Central America',
	'UserCountry_continent_oce' => 'Oceania',
	'UserSettings_VisitorSettings' => 'የጎበኚዎች ቅንብሮች',
	'UserSettings_BrowserFamilies' => 'የማሰሺያ ቤተሰቦች',
	'UserSettings_Browsers' => 'ማሰሻዎች',
	'UserSettings_Plugins' => 'ተሰኪዎች',
	'UserSettings_Configurations' => 'ውቅረቶች',
	'UserSettings_Resolutions' => 'ጥራቶች',
	'UserSettings_WideScreen' => 'ሰፊ ማያ',
	'UserSettings_ColumnBrowserFamily' => 'የማሰሻ ቤተሰብ',
	'UserSettings_ColumnBrowser' => 'ማሰሺያ',
	'UserSettings_ColumnPlugin' => 'ተሰኪ',
	'UserSettings_ColumnConfiguration' => 'ውቅረት',
	'UserSettings_ColumnResolution' => 'ጥራት',
	'UserSettings_ColumnTypeOfScreen' => 'የማያ ዓይነት',
	'UserSettings_WidgetResolutions' => 'የማያ ጥራቶች',
	'UserSettings_WidgetBrowsers' => 'የጎብኚ ማሰሻዎች',
	'UserSettings_WidgetPlugins' => 'የተሰኪዎች ዝርዝር',
	'UserSettings_WidgetWidescreen' => 'የተለመደ / ሰፊ ማያ',
	'UserSettings_WidgetBrowserFamilies' => 'ማሰሺያ በቤተሰብ',
	'UserSettings_WidgetOperatingSystems' => 'ስርዓተ ክወናዎች',
	'UserSettings_WidgetGlobalVisitors' => 'የሁሉም ጎብኚዎች ውቅረት',
	'UserSettings_SubmenuSettings' => 'ቅንብሮች',
	'UsersManager_UsersManagement' => 'የተጠቃሚዎች ምነጃ',
	'UsersManager_UsersManagementMainDescription' => 'አዳዲስ ተጤቃሚዎችን ይፍጠሩ ወይም ያሉትን ያልቁ።ፈቃዳቸውን ከላይ ማዘጋጀት ይቻላል.',
	'UsersManager_ManageAccess' => 'መድረሻ መንጅ',
	'UsersManager_MainDescription' => 'የትኞቹ ተጠቃሚዎች የትኛው በድር ጣቢያህ ላይ የፒዊክ መድረሻ እንዳላቸው ወስን። በሁሉም ድር ጣቢያዎች ላይ ፈቃዳቸውን በአንድ ጊዜ ማዘጋጀት ይቻላል።',
	'UsersManager_Sites' => 'ድር ጣቢያዎች',
	'UsersManager_AllWebsites' => 'ሁሉንም ድር ጣቢያዎች',
	'UsersManager_ApplyToAllWebsites' => 'በሁሉም ድር ጣቢያዎች ላይ  ተግብር',
	'UsersManager_User' => 'ተጠቃሚ',
	'UsersManager_PrivNone' => 'መድረሻ የለም',
	'UsersManager_PrivView' => 'ትእይታ',
	'UsersManager_PrivAdmin' => 'አስተዳዳሪ',
	'UsersManager_ChangeAllConfirm' => 'እርግጠኛ ነህ  \'%s\' የሁሉንም ድር ጣቢያዎች ፈቃድ መቀየር ትፈልጋለህ?',
	'UsersManager_Password' => 'የይለፍ ቃል',
	'UsersManager_Email' => 'ኢ-ሜይል',
	'UsersManager_Alias' => 'ተለዋጭ ስም',
	'UsersManager_Edit' => 'አርትእ',
	'UsersManager_AddUser' => 'አዲስ ተጤቃሚ ጨምር',
	'UsersManager_MenuUsers' => 'ተጠቃሚዎች',
	'UsersManager_DeleteConfirm_js' => 'እርግጠኛ ነህ ተጠቃሚዎቹን መሰረዝ ትፈልጋለህ %s?',
	'UsersManager_ExceptionLoginExists' => 'ግባ \'%s\' አስቀድሞ ማለት.',
	'UsersManager_ExceptionEmailExists' => 'በዚህ ኢ-ሜይል ተጠቃሚ \'%s\'አለ.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'ገባ በ %1$s እና %2$s በ ቁምፊ መካከል መሆን አለበት እንዲሁም ፊደላት፣ቁጥሮች ወይም ቁምፊ ብቻ መያዝ አለበት \'_\' ወይም \'-\' ወይም \'.\'',
	'UsersManager_ExceptionInvalidEmail' => 'ኢ-ሜይሉ ትክክለኛ ቅርፀት የለውም',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'ተጠቃሚው \'%s\' የለም ስለዚህ ሊሰረዝ አይችልም',
	'UsersManager_ExceptionAdminAnonymous' => 'የአስተዳዳሪን ፈቃድ ላልታወቀ ሰው መስጠት አይቻልም',
	'UsersManager_ExceptionEditAnonymous' => 'ያልታወቀው ተጠቃሚን መሰረዝ ወይም አርትእ አይቻልም። በፒዊክ ያልገባን ተጤቃሚ ለመግለፅ ይጠቅማል። ለምሳሌ የርስዎን ስታቲስቲክ \'የትይታ\' ፈቃድ \'ላልታወቀ\' ተጠቃሚ በመስጠት ግልፅ ማድረግ ትችላለህ።',
	'UsersManager_ExceptionSuperUser' => 'የተጠየቀው ተጠቃሚ ሊቀ ተጠቃሚ ስለሆነ በኤፒአይ ሊጠየቅ፣  አርትእ ወይም ሊሰረዝ አይችልም። ሊቀ ተጠቃሚውን ዝርዝር በፒዊክ ውቅረት ፋይል በእጅ አርትእ ይቻላል።',
	'UsersManager_ExceptionAccessValues' => 'የግቤት መድረሻ ከሚከተሉት አንዱ እሴት ሊኖረው ይገባል: [ %s ]',
	'VisitFrequency_Evolution' => 'Evolution በፔሬዱ ላይ',
	'VisitFrequency_ColumnReturningVisits' => 'መልስ ጉበኝቶች',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'በመልስ ጉብኝቶች የተወሰዱ ርምጃዎች',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'የመልስ ጉብኝቶች ተመላሽ ፍጥነት',
	'VisitFrequency_ReturnVisits' => '%s መልስ ጉብኝቶች',
	'VisitFrequency_ReturnActions' => '%s በመልስ ጉብኝቶች የተወሰዱ ርምጃዎች',
	'VisitFrequency_ReturnBounceRate' => '%s መልስ ጉብኝቶች ተመላሽ ሆነዋል (ከአንድ ድር ጣቢያ በኋላ ገፁን ትተዋል)',
	'VisitFrequency_WidgetOverview' => 'የድግግሞሽ አጠቃላይ እይታ',
	'VisitFrequency_WidgetGraphReturning' => 'የመልስ ጉብኝቶች ግራፍ',
	'VisitFrequency_SubmenuFrequency' => 'ድግግሞሽ',
	'VisitorInterest_VisitsPerDuration' => 'ጉብኝት ከጉብኝት ቆይታ ጋር',
	'VisitorInterest_VisitsPerNbOfPages' => 'ጉብኝት ከገፅ ቁጥር ጋር',
	'VisitorInterest_ColumnVisitDuration' => 'የጉብኝት ቆይታዎች',
	'VisitorInterest_ColumnPagesPerVisit' => 'ጉብኝት ከገፆች ጋር',
	'VisitorInterest_WidgetLengths' => 'የጉብኝት ርዝመት',
	'VisitorInterest_WidgetPages' => 'ጉብኝት ከገፆች ጋር',
	'VisitorInterest_PlusXMin' => '%s ደቂቃ',
	'VisitorInterest_OnePage' => '1 ገፅ',
	'VisitorInterest_NPages' => '%s ገፆች',
	'VisitsSummary_NbVisits' => '%s ጉበኝቶች',
	'VisitsSummary_NbUniqueVisitors' => '%s የተለዩ ጎብኚዎች',
	'VisitsSummary_MaxNbActions' => '%s በአንድ ጉብኝት የተወሰዱ ከፍተኛ ርምጃዎች',
	'VisitsSummary_NbVisitsBounced' => '%s የተመለሱ ጉብኝቶች (ከአንድ ገፅ በኋላ ገፁን የተዉ)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolution በመጨረሻው ላይ %s',
	'VisitsSummary_GenerateTime' => '%s ሰከንዶች ገፁን ለማመንጨት',
	'VisitsSummary_GenerateQueries' => '%s ጥያቄዎች ተሰርተዋል',
	'VisitsSummary_WidgetLastVisits' => 'የመጨረሻው ጉብኝቶች ግራፍ',
	'VisitsSummary_WidgetVisits' => 'የጉብኝቶች አጠቃላይ እይታ',
	'VisitsSummary_WidgetLastVisitors' => 'የመጨረሻው የተለዩ ጎብኚዎች ግራፍ',
	'VisitsSummary_WidgetOverviewGraph' => 'አጠቃላይ እይታ ከግራፍ ጋር',
	'VisitsSummary_SubmenuOverview' => 'አጠቃላይ እይታ ከግራፍ ጋር',
	'VisitTime_LocalTime' => 'ጉብኝቶች ከአካባቢያዊ ሰዓት',
	'VisitTime_ServerTime' => 'ጉብኝቶች ከአገልጋይ ሰዓት',
	'VisitTime_ColumnServerTime' => 'የአገልጋይ ሰዓት',
	'VisitTime_ColumnLocalTime' => 'አካባቢያዊ ሰዓት',
	'VisitTime_WidgetLocalTime' => 'ጉብኝቶች በአካባቢያዊ ሰዓት',
	'VisitTime_WidgetServerTime' => 'ጉብኝቶች በአገልጋይ ሰዓት',
	'VisitTime_SubmenuTimes' => 'ሰዓታት',
	'VisitTime_NHour' => '%sh',
);
